@@ -11,7 +11,7 @@
 #include <Akri_CDFEM_Support.hpp>
 #include <Akri_CDMesh.hpp>
 #include <Akri_DiagWriter.hpp>
-#include <Akri_AdaptivityInterface.hpp>
+#include <Akri_FieldRef.hpp>
 #include <Akri_AdaptivityHelpers.hpp>
 #include <Akri_BoundingBoxMesh.hpp>
 #include <Akri_MeshInputOptions.hpp>
@@ -24,6 +24,7 @@
 #include <Akri_LevelSet.hpp>
 #include <Akri_CreateInterfaceGeometry.hpp>
 #include <Akri_MeshHelpers.hpp>
+#include <Akri_MeshInterface.hpp>
 #include <Akri_Phase_Support.hpp>
 #include <Akri_ResultsOutputOptions.hpp>
 #include <Akri_Simulation.hpp>
@@ -36,9 +37,12 @@
 #include <stk_util/parallel/ParallelReduceBool.hpp>
 #include <Akri_BoundingSurface.hpp>
 #include <Akri_CDMesh_Refinement.hpp>
+#include <Akri_MeshFromFile.hpp>
+#include <Akri_OutputUtils.hpp>
 #include <Akri_Surface_Manager.hpp>
 #include <Akri_RefinementInterface.hpp>
 #include <Akri_RefinementSupport.hpp>
+#include <Ioss_GroupingEntity.h>
 
 namespace krino{
 
@@ -46,24 +50,18 @@ namespace krino{
 
 Region::Region(Simulation & owning_simulation, const std::string & regionName)
 : my_simulation(owning_simulation),
-  my_meta(nullptr),
-  my_bulk(nullptr),
   my_name(regionName),
   my_timerRegion(std::string("Region ") + regionName, sierra::Diag::TIMER_REGION, my_simulation.get_timer()),
   my_timerInitialize("Initialize", my_timerRegion),
   my_timerExecute("Execute", my_timerRegion),
   my_timerMeshInput("Mesh input", my_timerRegion),
   my_timerMeshOutput("Mesh output", my_timerRegion),
-  my_output_file_index(0),
-  my_output_file_created(false)
+  myOutputFileIndex(0),
+  myOutputFileNumRevisions(0),
+  myIsOutputFileCreatedAndCurrent(false)
 { /* %TRACE[ON]% */ Trace trace__("krino::Region::Region()"); /* %TRACE% */
   my_simulation.add_region(this);
-  myIOBroker = std::make_unique<stk::io::StkMeshIoBroker>(stk::EnvData::parallel_comm());
-  myIOBroker->use_simple_fields();
-
-  std::vector<std::string> entity_rank_names = stk::mesh::entity_rank_names();
-  entity_rank_names.push_back("FAMILY_TREE");
-  stk_IO().set_rank_name_vector(entity_rank_names);
+  myOutputBroker = std::make_unique<stk::io::StkMeshIoBroker>(stk::EnvData::parallel_comm());
 
   my_results_options = std::make_unique<ResultsOutputOptions>();
 }
@@ -96,7 +94,7 @@ static bool cdfem_mesh_displacements_requested_in_results_fields(const std::stri
 void Region::commit()
 { /* %TRACE[ON]% */ Trace trace__("krino::Region::commit()"); /* %TRACE% */
 
-  auto & meta = get_stk_mesh_meta_data();
+  auto & meta = mesh_meta_data();
   LevelSet::setup(meta);
   CDFEM_Support & cdfem_support = CDFEM_Support::get(meta);
   RefinementSupport & refinementSupport = RefinementSupport::get(meta);
@@ -119,13 +117,14 @@ void Region::commit()
       (krino::CDFEM_Support::is_active(meta) && cdfem_support.get_post_cdfem_refinement_levels() > 0))
   {
     auto_aura_option = stk::mesh::BulkData::AUTO_AURA;
-    RefinementInterface & refinement = create_refinement(meta, refinementSupport.get_use_percept(), my_timerExecute);
+    RefinementInterface & refinement = KrinoRefinement::create(meta);
     refinementSupport.set_non_interface_conforming_refinement(refinement);
   }
 
   if (cdfem_support.get_cdfem_edge_degeneracy_handling() == SNAP_TO_INTERFACE_WHEN_QUALITY_ALLOWS_THEN_SNAP_TO_NODE)
   {
     auto_aura_option = stk::mesh::BulkData::AUTO_AURA;
+    cdfem_support.register_cdfem_snap_displacements_field();
   }
 
   if (krino::CDFEM_Support::is_active(meta))
@@ -139,43 +138,27 @@ void Region::commit()
     cdfem_support.finalize_fields();
   }
 
-  if (nullptr != my_generated_mesh.get())
+  MeshInputOptions * db_options = MeshInputOptions::get(my_input_model_name);
+  STK_ThrowRequire(db_options != nullptr && db_options->is_valid());
+  if (db_options->use_generated_mesh())
   {
     set_generated_mesh_domain();
-    my_generated_mesh->populate_mesh(stk::EnvData::parallel_comm(), auto_aura_option);
-    my_bulk = &my_generated_mesh->bulk_data();
-    stk_IO().set_bulk_data( *my_bulk );
-    if (my_generated_mesh->has_flat_boundaries())
-      my_generated_mesh->create_domain_sides();
-  }
-  else
-  {
-    std::shared_ptr<stk::mesh::BulkData> shared_bulk = stk::mesh::MeshBuilder(stk::EnvData::parallel_comm()).set_aura_option(auto_aura_option).create(std::shared_ptr<stk::mesh::MetaData>(&meta,[](auto ptrWeWontDelete){}));
-    my_bulk = shared_bulk.get();
-    my_bulk->mesh_meta_data().use_simple_fields();
-    stk_IO().set_bulk_data( shared_bulk );
-    stk_IO().populate_bulk_data();
   }
 
-  if (AuxMetaData::get(get_stk_mesh_meta_data()).get_assert_32bit_flag())
+  myMesh->populate_mesh(auto_aura_option);
+  stkOutput().set_bulk_data( mesh_bulk_data() );
+
+  if (AuxMetaData::get(mesh_meta_data()).get_assert_32bit_flag())
   {
-    const bool has_64bit_ids_in_use = stk::is_true_on_any_proc(my_bulk->parallel(), locally_has_64bit_ids_in_use_for_nodes_or_elements(*my_bulk));
+    const bool has_64bit_ids_in_use = stk::is_true_on_any_proc(mesh_bulk_data().parallel(), locally_has_64bit_ids_in_use_for_nodes_or_elements(mesh_bulk_data()));
     STK_ThrowErrorMsgIf(has_64bit_ids_in_use, "Option use_32_bit ids is active, but input file uses 64 bit ids.");
   }
   else
   {
-    my_bulk->set_large_ids_flag(true);
+    mesh_bulk_data().set_large_ids_flag(true);
   }
 
-  if (my_bulk->is_automatic_aura_on() || my_bulk->parallel_size() == 1)
-  {
-    // Used for element side connectivty checks
-    stk::mesh::create_exposed_block_boundary_sides(*my_bulk, meta.universal_part(), {&AuxMetaData::get(meta).exposed_boundary_part()});
-  }
-
-
-
-  activate_all_entities(*my_bulk, active_part);
+  activate_all_entities(mesh_bulk_data(), active_part);
 
   LevelSet::post_commit_setup(meta);
 }
@@ -204,13 +187,15 @@ void zero_error_indicator(stk::mesh::BulkData & mesh)
 static void refine_elements_near_interface(RefinementInterface & refinement,
     const RefinementSupport & refinementSupport,
     stk::mesh::BulkData & mesh,
-    const int numRefinementSteps)
+    const int numRefinementSteps,
+    const bool doInitializeLS)
 {
   std::function<void(int)> mark_elements_near_interface =
-      [&mesh, &refinementSupport, numRefinementSteps]
+      [&mesh, &refinementSupport, numRefinementSteps, doInitializeLS]
        (int num_refinements)
       {
-        LevelSet::initialize(mesh.mesh_meta_data());
+        if (doInitializeLS)
+          LevelSet::initialize(mesh.mesh_meta_data());
         if (num_refinements < numRefinementSteps)
         {
           const std::unique_ptr<InterfaceGeometry> interfaceGeometry = create_interface_geometry(mesh.mesh_meta_data());
@@ -228,13 +213,15 @@ static void refine_elements_near_interface(RefinementInterface & refinement,
 static void refine_interface_elements(RefinementInterface & refinement,
     const RefinementSupport & refinementSupport,
     stk::mesh::BulkData & mesh,
-    const int numRefinementSteps)
+    const int numRefinementSteps,
+    const bool doInitializeLS)
 {
   std::function<void(int)> marker_function =
-      [&mesh, &refinementSupport, numRefinementSteps]
+      [&mesh, &refinementSupport, numRefinementSteps, doInitializeLS]
        (int num_refinements)
       {
-        LevelSet::initialize(mesh.mesh_meta_data());
+        if (doInitializeLS)
+          LevelSet::initialize(mesh.mesh_meta_data());
         if(num_refinements < numRefinementSteps)
         {
           const auto & auxMeta = krino::AuxMetaData::get(mesh.mesh_meta_data());
@@ -255,6 +242,7 @@ static void refine_elements_that_intersect_interval(RefinementInterface & refine
       [&mesh, &refinementSupport, numRefinementSteps]
        (int num_refinements)
       {
+        constexpr bool isDefaultCoarsen = true;
         LevelSet::initialize(mesh.mesh_meta_data());
         if (num_refinements < numRefinementSteps)
         {
@@ -262,8 +250,9 @@ static void refine_elements_that_intersect_interval(RefinementInterface & refine
           krino::mark_elements_that_intersect_interval(mesh,
               refinementSupport.get_non_interface_conforming_refinement(),
               *interfaceGeometry,
-              refinementSupport,
-              num_refinements);
+              refinementSupport.get_refinement_interval(),
+              refinementSupport.get_interface_minimum_refinement_level(),
+              isDefaultCoarsen);
         }
       };
 
@@ -294,7 +283,7 @@ static void refine_based_on_indicator_field(RefinementInterface & refinement,
   perform_multilevel_adaptivity(refinement, mesh, marker_function, refinementSupport.get_do_not_refine_or_unrefine_selector());
 }
 
-void do_adaptive_refinement(const krino::RefinementSupport & refinementSupport, stk::mesh::BulkData & mesh)
+void do_adaptive_refinement(const krino::RefinementSupport & refinementSupport, const bool doInitializeLS, stk::mesh::BulkData & mesh)
 {
   stk::diag::TimeBlock adapt_timer__(refinementSupport.get_timer());
 
@@ -317,10 +306,10 @@ void do_adaptive_refinement(const krino::RefinementSupport & refinementSupport,
     if (doNearbyRefinementBeforeInterfaceRefinement)
     {
       const int numNearbyRefinementSteps = numRefinementLevels;
-      refine_elements_near_interface(refinement, refinementSupport, mesh, numNearbyRefinementSteps);
+      refine_elements_near_interface(refinement, refinementSupport, mesh, numNearbyRefinementSteps, doInitializeLS);
     }
     const int numInterfaceRefinementSteps = doNearbyRefinementBeforeInterfaceRefinement ? numRefinementLevels : (2*numRefinementLevels); // Make sure refinement completes so that interfacial elements are fully refined
-    refine_interface_elements(refinement, refinementSupport, mesh, numInterfaceRefinementSteps);
+    refine_interface_elements(refinement, refinementSupport, mesh, numInterfaceRefinementSteps, doInitializeLS);
   }
 }
 
@@ -370,7 +359,6 @@ void do_post_cdfem_uniform_refinement(const Simulation & simulation, const CDFEM
     else
     {
       krinolog << "Performing " << num_levels << " levels of post-cdfem mesh refinement..." << std::endl;
-      STK_ThrowRequireMsg(!refinementSupport.get_use_percept(), "Percept cannot be used with post-cdfem refinement.");
 
       // Doing adaptive refinement with a uniform marker is better than doing uniform refinement here because of how
       // the transition elements are handled.
@@ -394,14 +382,15 @@ void Region::initialize()
 { /* %TRACE[ON]% */ Trace trace__("krino::Region::initialize()"); /* %TRACE% */
   stk::diag::TimeBlock timer__(my_timerInitialize);
 
-  const bool cdfem_is_active = krino::CDFEM_Support::is_active(get_stk_mesh_meta_data());
-  krino::CDFEM_Support & cdfem_support = krino::CDFEM_Support::get(get_stk_mesh_meta_data());
-  const RefinementSupport & refinementSupport = RefinementSupport::get(get_stk_mesh_meta_data());
-  const Surface_Manager & surfaceManager = Surface_Manager::get(get_stk_mesh_meta_data());
+  const bool cdfem_is_active = krino::CDFEM_Support::is_active(mesh_meta_data());
+  krino::CDFEM_Support & cdfem_support = krino::CDFEM_Support::get(mesh_meta_data());
+  const RefinementSupport & refinementSupport = RefinementSupport::get(mesh_meta_data());
+  const Surface_Manager & surfaceManager = Surface_Manager::get(mesh_meta_data());
 
-  auto & bulk = get_stk_mesh_bulk_data();
-  const auto & auxMeta = AuxMetaData::get(get_stk_mesh_meta_data());
+  auto & bulk = mesh_bulk_data();
+  const auto & auxMeta = AuxMetaData::get(mesh_meta_data());
 
+  const bool doInitializeLSDuringRefinement = true;
   const bool doRefinement = refinementSupport.get_initial_refinement_levels() > 0 ||
       refinementSupport.get_interface_maximum_refinement_level() > 0 ||
       refinementSupport.get_post_adapt_refinement_levels() > 0;
@@ -414,7 +403,7 @@ void Region::initialize()
     if (refinementSupport.get_initial_refinement_levels() > 0)
       refinement.do_uniform_refinement(refinementSupport.get_initial_refinement_levels());
 
-    do_adaptive_refinement(refinementSupport, bulk);
+    do_adaptive_refinement(refinementSupport, doInitializeLSDuringRefinement, bulk);
 
     do_post_adapt_uniform_refinement(my_simulation, refinementSupport, auxMeta, bulk);
   }
@@ -424,16 +413,16 @@ void Region::initialize()
     const int num_init_decomp_cycles = cdfem_support.get_num_initial_decomposition_cycles();
     for (int icycle=0; icycle<num_init_decomp_cycles; ++icycle)
     {
-      LevelSet::initialize(get_stk_mesh_meta_data());
+      LevelSet::initialize(mesh_meta_data());
       if (icycle >= num_init_decomp_cycles-1)
-        LevelSet::clear_initialization_data(get_stk_mesh_meta_data()); // reclaim memory, harmless to call multiple times after we are done initializing
-      const std::unique_ptr<InterfaceGeometry> interfaceGeometry = create_interface_geometry(get_stk_mesh_meta_data());
+        LevelSet::clear_initialization_data(mesh_meta_data()); // reclaim memory, harmless to call multiple times after we are done initializing
+      const std::unique_ptr<InterfaceGeometry> interfaceGeometry = create_interface_geometry(mesh_meta_data());
       krino::CDMesh::decompose_mesh(bulk, *interfaceGeometry, my_simulation.get_time_step_count(), {});
     }
 
     do_post_cdfem_uniform_refinement(my_simulation, cdfem_support, refinementSupport, auxMeta, bulk);
 
-    for (auto && part : krino::Phase_Support::get(get_stk_mesh_meta_data()).get_nonconformal_parts())
+    for (auto && part : krino::Phase_Support::get(mesh_meta_data()).get_nonconformal_parts())
     {
       if (stk::io::is_part_io_part(*part)) stk::io::remove_io_part_attribute(*part);
     }
@@ -447,7 +436,7 @@ void Region::initialize()
       if (my_simulation.is_transient())
       {
         // initialize does not end with the facets constructed so manually construct them now
-        ls->build_facets_locally(get_stk_mesh_meta_data().universal_part());
+        ls->build_facets_locally(mesh_meta_data().universal_part());
 
         // debugging
         if (krinolog.shouldPrint(LOG_FACETS))
@@ -458,23 +447,9 @@ void Region::initialize()
     }
   }
 
-  LevelSet::clear_initialization_data(get_stk_mesh_meta_data()); // reclaim memory, harmless to call multiple times after we are done initializing
+  LevelSet::clear_initialization_data(mesh_meta_data()); // reclaim memory, harmless to call multiple times after we are done initializing
 
-  // Skip output of empty parts
-  for (auto && part : get_stk_mesh_meta_data().get_parts())
-  {
-    if (stk::io::is_part_io_part(*part))
-    {
-      uint64_t numEntities = stk::mesh::count_selected_entities(*part & auxMeta.active_part(), get_stk_mesh_bulk_data().buckets(part->primary_entity_rank()));
-      const uint64_t localNumEntities = numEntities;
-      stk::all_reduce_sum(get_stk_mesh_bulk_data().parallel(), &localNumEntities, &numEntities, 1);
-      if(numEntities == 0)
-      {
-        krinolog << "Skipping output of empty part " << part->name() << stk::diag::dendl;
-        stk::io::remove_io_part_attribute(*part);
-      }
-    }
-  }
+  turn_off_output_for_empty_io_parts(mesh_bulk_data(), auxMeta.active_part());
 }
 //--------------------------------------------------------------------------------
 
@@ -483,61 +458,89 @@ void Region::execute()
   stk::diag::TimeBlock timer__(my_timerExecute);
 
   // This is a hack for now to exit immediately when CDFEM is active
-  if (krino::CDFEM_Support::is_active(get_stk_mesh_meta_data()))
+  if (krino::CDFEM_Support::is_active(mesh_meta_data()))
   {
     return;
   }
 
-  double deltaTime = time_step();
+  const RefinementSupport & refinementSupport = RefinementSupport::get(mesh_meta_data());
+  const bool doRefinement = refinementSupport.get_interface_maximum_refinement_level() > 0 ||
+      refinementSupport.get_post_adapt_refinement_levels() > 0;
 
-  const Surface_Manager & surfaceManager = Surface_Manager::get(get_stk_mesh_meta_data());
+  if (doRefinement)
+  {
+    const bool doInitializeLSDuringRefinement = false;
+    auto & bulk = mesh_bulk_data();
+    const auto & auxMeta = AuxMetaData::get(mesh_meta_data());
+
+    do_adaptive_refinement(refinementSupport, doInitializeLSDuringRefinement, bulk);
+    do_post_adapt_uniform_refinement(my_simulation, refinementSupport, auxMeta, bulk);
+    mesh_topology_has_changed();
+  }
+
+  const double deltaTime = time_step();
+  const double timeN = get_current_time();
+  const double timeNP1 = timeN + deltaTime;
+
+  const Surface_Manager & surfaceManager = Surface_Manager::get(mesh_meta_data());
   for(auto&& ls : surfaceManager.get_levelsets())
   {
-    ls->advance_semilagrangian(deltaTime);
+    ls->advance_semilagrangian(timeN, timeNP1);
   }
 }
 
-unsigned Region::spatial_dimension() const { return my_meta->spatial_dimension(); }
-const stk::mesh::BulkData& Region::get_stk_mesh_bulk_data() const { STK_ThrowRequire(my_bulk); return *my_bulk; }
-stk::mesh::BulkData& Region::get_stk_mesh_bulk_data() { STK_ThrowRequire(my_bulk); return *my_bulk; }
-const stk::mesh::MetaData& Region::get_stk_mesh_meta_data() const { STK_ThrowRequire(my_meta); return *my_meta; }
-stk::mesh::MetaData& Region::get_stk_mesh_meta_data() { STK_ThrowRequire(my_meta); return *my_meta; }
+unsigned Region::spatial_dimension() const { return mesh_meta_data().spatial_dimension(); }
+const stk::mesh::BulkData& Region::mesh_bulk_data() const { return myMesh->bulk_data(); }
+stk::mesh::BulkData& Region::mesh_bulk_data() { return myMesh->bulk_data(); }
+const stk::mesh::MetaData& Region::mesh_meta_data() const { return myMesh->meta_data(); }
+stk::mesh::MetaData& Region::mesh_meta_data() { return myMesh->meta_data(); }
 double Region::time_step() const { return my_simulation.get_time_step(); }
+double Region::get_current_time() const { return my_simulation.get_current_time(); }
 
-stk::io::StkMeshIoBroker & Region::stk_IO()
+stk::io::StkMeshIoBroker & Region::stkOutput()
 {
-  STK_ThrowRequire(myIOBroker);
-  return *myIOBroker;
-}
-
-Ioss::Region * Region::get_input_io_region()
-{
-  return stk_IO().get_input_ioss_region().get();
-}
-
-std::string Region::name_of_input_mesh() const
-{
-  return my_input_model_name;
+  STK_ThrowRequire(myOutputBroker);
+  return *myOutputBroker;
 }
 
 void Region::create_output_mesh()
 {
+  myIsOutputFileCreatedAndCurrent = true;
+
   bool output_mesh = my_results_options->get_num_step_increments() != 0;
 
   if(!output_mesh) return;
 
   my_results_options->get_scheduler().set_termination_time(my_simulation.get_stop_time());
 
-  my_output_file_index = stk_IO().create_output_mesh(my_results_options->get_filename(), stk::io::WRITE_RESULTS, my_results_options->get_properties());
+  const std::string baseFileName = my_results_options->get_filename();
+  Ioss::PropertyManager fileProperties(my_results_options->get_properties());
+  fileProperties.add(Ioss::Property("base_filename", baseFileName));
 
-  std::shared_ptr<stk::mesh::Selector> active_selector = std::make_shared<stk::mesh::Selector>(AuxMetaData::get(get_stk_mesh_meta_data()).active_part());
-  stk_IO().set_subset_selector(my_output_file_index, active_selector);
+  std::string filename = baseFileName;
+  if (myOutputFileNumRevisions > 0)
+  {
+    std::shared_ptr<Ioss::Region> ioRegion = stkOutput().get_output_ioss_region(myOutputFileIndex);
+    int stateCount = ioRegion->get_property("state_count").get_int();
+    if (ioRegion->property_exists("state_offset"))
+      stateCount += ioRegion->get_property("state_offset").get_int();
+    filename = create_filename_from_base_filename(baseFileName, myOutputFileNumRevisions);
+    fileProperties.add(Ioss::Property("state_offset", stateCount));
+  }
 
-  stk_IO().write_output_mesh(my_output_file_index);
+  stkOutput().use_simple_fields();
+  const auto oldOutputFileIndex = myOutputFileIndex;
+  myOutputFileIndex = stkOutput().create_output_mesh(filename, stk::io::WRITE_RESULTS, fileProperties);
 
-  declare_output_variables(my_output_file_index);
+  if (myOutputFileNumRevisions > 0)
+    stkOutput().close_output_mesh(oldOutputFileIndex);
 
-  my_output_file_created = true;
+  std::shared_ptr<stk::mesh::Selector> active_selector = std::make_shared<stk::mesh::Selector>(AuxMetaData::get(mesh_meta_data()).active_part());
+  stkOutput().set_subset_selector(myOutputFileIndex, active_selector);
+
+  declare_output_variables(myOutputFileIndex);
+
+  myOutputFileNumRevisions++;
 }
 
 void
@@ -547,19 +550,19 @@ Region::declare_output_variables(size_t result_output_index)
   {
     const std::string & varName = outField.first;
     const std::string & newName = outField.second;
-    stk::mesh::FieldBase *theField = get_stk_mesh_meta_data().get_field(stk::topology::NODE_RANK, varName);
+    stk::mesh::FieldBase *theField = mesh_meta_data().get_field(stk::topology::NODE_RANK, varName);
     if ( nullptr == theField )
     {
       krinolog << "Sorry, no nodal field by the name " << varName << std::endl;
       krinolog << "Available fields: " << std::endl;
-      for (auto && field : get_stk_mesh_meta_data().get_fields(stk::topology::NODE_RANK))
+      for (auto && field : mesh_meta_data().get_fields(stk::topology::NODE_RANK))
       {
         krinolog << "  " << field->name() << std::endl;
       }
     }
     else
     {
-      stk_IO().add_field(result_output_index, *theField, newName);
+      stkOutput().add_field(result_output_index, *theField, newName);
     }
   }
 
@@ -567,19 +570,19 @@ Region::declare_output_variables(size_t result_output_index)
   {
     const std::string & varName = outField.first;
     const std::string & newName = outField.second;
-    stk::mesh::FieldBase *theField = get_stk_mesh_meta_data().get_field(stk::topology::ELEMENT_RANK, varName);
+    stk::mesh::FieldBase *theField = mesh_meta_data().get_field(stk::topology::ELEMENT_RANK, varName);
     if ( nullptr == theField )
     {
       krinolog << "Sorry, no element field by the name " << varName << std::endl;
       krinolog << "Available fields: " << std::endl;
-      for (auto && field : get_stk_mesh_meta_data().get_fields(stk::topology::ELEMENT_RANK))
+      for (auto && field : mesh_meta_data().get_fields(stk::topology::ELEMENT_RANK))
       {
         krinolog << "  " << field->name() << std::endl;
       }
     }
     else
     {
-      stk_IO().add_field(result_output_index, *theField, newName);
+      stkOutput().add_field(result_output_index, *theField, newName);
     }
   }
 }
@@ -601,13 +604,9 @@ void Region::process_output(bool forceOutput)
 
   if(!doOutput) return;
 
-  // A couple of krino tests that just compute surface distances never call Region::initialize()
-  // where we normally create the output mesh.
-  if(!my_output_file_created) create_output_mesh();
+  if(!myIsOutputFileCreatedAndCurrent) create_output_mesh();
 
-  stk_IO().begin_output_step(my_output_file_index, currentTime);
-  stk_IO().write_defined_output_fields(my_output_file_index);
-  stk_IO().end_output_step(my_output_file_index);
+  stkOutput().process_output_request(myOutputFileIndex, currentTime);
 }
 
 void
@@ -623,45 +622,25 @@ Region::associate_input_mesh(const std::string & model_name, bool assert_32bit_i
   if (db_options->use_generated_mesh())
   {
     stk::topology generated_mesh_element_type = db_options->get_generated_mesh_element_type();
-    std::vector<std::string> entity_rank_names = stk::mesh::entity_rank_names();
-    entity_rank_names.push_back("FAMILY_TREE");
-    my_generated_mesh = std::make_unique<BoundingBoxMesh>(generated_mesh_element_type,entity_rank_names);
-    my_meta = &my_generated_mesh->meta_data();
-    stk::mesh::Field<double> & coordsField = my_meta->declare_field<double>(stk::topology::NODE_RANK, "coordinates", 1);
-    stk::mesh::put_field_on_mesh(coordsField, my_meta->universal_part(), generated_mesh_element_type.dimension(), nullptr);
+    myMesh = std::make_unique<BoundingBoxMesh>(generated_mesh_element_type, stk::EnvData::parallel_comm());
   }
   else
   {
-    const std::string directory = sierra::Env::working_directory().c_str();
-    const std::string filename(Ioss::Utils::local_filename(db_options->get_filename(), db_options->get_filetype(), directory));
-
-    stk::io::StkMeshIoBroker & stk_io = stk_IO();
-
-    stk_io.property_add(Ioss::Property("MAXIMUM_NAME_LENGTH", 180));
-
-    if (!db_options->get_decomposition_method().empty())
-    {
-      stk_io.property_add(Ioss::Property("DECOMPOSITION_METHOD", Ioss::Utils::uppercase(db_options->get_decomposition_method())));
-    }
-
-    stk_io.add_mesh_database(db_options->get_filename(), stk::io::READ_MESH);
-    stk_io.create_input_mesh();
-    my_meta = &stk_io.meta_data();
-    AuxMetaData::create(*my_meta);
+    myMesh = std::make_unique<MeshFromFile>(db_options->get_filename(), stk::EnvData::parallel_comm(), db_options->get_decomposition_method());
   }
 
   {
-    stk::mesh::Selector activeSelector = AuxMetaData::get(*my_meta).active_part();
-    stk_IO().set_active_selector(activeSelector);
+    stk::mesh::Selector activeSelector = AuxMetaData::get(mesh_meta_data()).active_part();
+    stkOutput().set_active_selector(activeSelector);
   }
 
   if (assert_32bit_ids)
   {
-    AuxMetaData::get(*my_meta).set_assert_32bit_flag();
+    AuxMetaData::get(mesh_meta_data()).set_assert_32bit_flag();
   }
   if (!force_64bit_ids)
   {
-    AuxMetaData::get(*my_meta).clear_force_64bit_flag();
+    AuxMetaData::get(mesh_meta_data()).clear_force_64bit_flag();
   }
 }
 
@@ -670,7 +649,9 @@ Region::set_generated_mesh_domain()
 {
   MeshInputOptions * db_options = MeshInputOptions::get(my_input_model_name);
   STK_ThrowRequire(db_options != nullptr);
-  my_generated_mesh->set_mesh_structure_type(db_options->get_generated_mesh_structure_type());
+  BoundingBoxMesh* bboxMesh = dynamic_cast<BoundingBoxMesh*>(myMesh.get());
+  STK_ThrowRequire(bboxMesh != nullptr);
+  bboxMesh->set_mesh_structure_type(db_options->get_generated_mesh_structure_type());
   const double mesh_size = db_options->get_generated_mesh_size();
   if (db_options->get_generated_mesh_domain_type() == MeshInputOptions::GENERATED_MESH_FOR_SPECIFIED_DOMAIN)
   {
@@ -692,12 +673,12 @@ Region::set_generated_mesh_domain()
       STK_ThrowRequireMsg(max[0]>min[0] && max[1]>min[1] && max[2]>min[2], "Invalid domain specified.");
       bbox = BoundingBoxMesh::BoundingBoxType(min, max);
     }
-    my_generated_mesh->set_domain(bbox, mesh_size);
+    bboxMesh->set_domain(bbox, mesh_size);
   }
   else
   {
     typename BoundingBoxMesh::BoundingBoxType domain_bbox;
-    const Surface_Manager & surfaceManager = Surface_Manager::get(get_stk_mesh_meta_data());
+    const Surface_Manager & surfaceManager = Surface_Manager::get(mesh_meta_data());
     for(auto&& ls : surfaceManager.get_levelsets())
     {
       if (ls->has_IC_surfaces())
@@ -725,7 +706,7 @@ Region::set_generated_mesh_domain()
       max[2] = 0.;
       domain_bbox = typename BoundingBoxMesh::BoundingBoxType(min, max);
     }
-    my_generated_mesh->set_domain(domain_bbox, mesh_size, 1);
+    bboxMesh->set_domain(domain_bbox, mesh_size, 1);
   }
 }
 
