@@ -519,6 +519,7 @@ void ParameterList::modifyParameterList(ParameterList & valid_pl,
   RCP<const ParameterListModifier> modifier;
   if (nonnull(modifier = valid_pl.getModifier())) {
     modifier->modify(*this, valid_pl);
+    this->setModifier(modifier);
   }
   ConstIterator itr;
   for (itr = valid_pl.begin(); itr != valid_pl.end(); ++itr){
@@ -696,7 +697,15 @@ void ParameterList::validateParametersAndSetDefaults(
           validEntry.getAny(),
           true // isDefault
           );
-        newEntry.setValidator(validEntry.validator());
+        RCP<const ParameterEntryValidator> validator;
+        if (nonnull(validator=validEntry.validator())) {
+#if defined(HAVE_TEUCHOS_MODIFY_DEFAULTS_DURING_VALIDATION)
+          validEntry.validator()->validateAndModify(this->name(itr), validEntryName, &newEntry);
+          // validateAndModify changes the default status so we reset it
+          newEntry.setAnyValue(newEntry.getAny(), true);
+#endif
+          newEntry.setValidator(validator);
+        }
         this->setEntry(validEntryName,newEntry);
       }
     }
